@@ -9,6 +9,7 @@ import shutil
 from faker.providers.person.en import Provider
 import numpy as np
 import pandas as pd
+import time
 
 GB = 1024 * 1024 * 1024
 MB = 1024 * 1024
@@ -296,32 +297,62 @@ def five_column_100_row_dataset():
 
 
 @pytest.fixture(scope="session")
-def batch():
-    size = 10000
+def batch_rows():
+    return 10000
+
+
+@pytest.fixture(scope="session")
+def generate_batch(batch_rows):
+    start = time.time()
+    size = batch_rows
     df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
     df['First'] = random_names('first_names', size)
     df['Last'] = random_names('last_names', size)
     df['Gender'] = random_genders(size)
     df['BirthDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
     df['StartDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
-    return to_dc_format(df)
+    end = time.time()
+    return [to_dc_format(df), end - start]
 
 
 @pytest.fixture(scope="session", params=[1, 10, 100, 1000])
-def load_data(connector, batch, good_object_id, mapping_object, _replace, request, batch_size):
-    size = request.param
+def num_gigs(request):
+    return request.param
+
+
+@pytest.fixture(scope="session")
+def load_data(connector, generate_batch, good_object_id, mapping_object, _replace, num_gigs, batch_size, batch_rows):
+    start = time.time()
+    size = num_gigs
     total_batches = (size * GB) / batch_size
     batch_number = 1
     rows_loaded = 0
-    connector.load_data(batch, good_object_id, mapping_object, _replace, batch_number, total_batches)
+    generate_data_time = 0
+
+    batch = generate_batch
+    generate_data_time += batch[1]
+    connector.load_data(batch[0], good_object_id, mapping_object, _replace, batch_number, total_batches)
 
     while batch_number <= total_batches:
-        rows_loaded += len(batch)
-        print(f"Loaded {rows_loaded} rows out of {total_batches * len(batch)}")
+        rows_loaded += len(batch[0])
+        print(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}")
         batch_number += 1
-        connector.load_data(batch, good_object_id, mapping_object, _replace, batch_number, total_batches)
+        batch = generate_batch
+        generate_data_time += batch[1]
+        connector.load_data(batch[0], good_object_id, mapping_object, _replace, batch_number, total_batches)
 
-    print(f"Loaded {rows_loaded} rows out of {total_batches * len(batch)}.\nTotal size uploaded: {size * GB}")
+    end = time.time()
+    print(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}.\nTotal size uploaded: {size * GB}")
+
+    elapsed_time = end - start - generate_data_time
+    hours = elapsed_time / (60 * 60)
+    minutes = (elapsed_time % (60 * 60)) / 60
+    seconds = (elapsed_time % (60 * 60)) % 60
+    formatted_time = f"{hours} Hours {minutes} Minutes and {seconds} seconds"
+
+    print(f"Time elapsed to load {num_gigs} GB: " + formatted_time)
+    print(f"\t({end - start} total seconds - {generate_data_time} seconds to generate data)")
+    assert elapsed_time < 10 * 60
     return True
 
 
